==> libapache-mod-musicindex_1.1.2.orig.tar.gz: libapache-mod-musicindex-1.1.2/src/playlist.h <==
/*
 *  playlist.h
 *  mod_musicindex
 *
 *  $Id: playlist.h 648 2006-07-05 23:35:34Z varenet $
 *
 *  Created by Thibaut VARENE on Thu Mar 20 2003.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef PLAYLIST_H
#define PLAYLIST_H

#include "mod_musicindex.h"

/**
 * Function pointer type, as we need it.
 *
 * Here comes the declaration of the funny part... We will (again) use
 * function pointers which will allocate a new entry  from the apache pool,
 * fill it, and close the "in" file if they recognise the file.
 */
typedef mu_ent* (*make_entry_ptr)(request_rec *, apr_pool_t *, FILE *const, mu_ent *const,
				const mu_config *const, mu_ent_names *const);

/**
 * Enumerate handlers to access relevant data in struct filetype.
 * FT_MAX is the last element of the enum, it's a marker that gives
 * us the size of the corresponding array.
 *
 * @warning <b>BEWARE</b>: you must keep that in a coherent order wrt
 * struct filetype[] !
 */
enum { FT_MP3, FT_OGG, FT_FLAC, FT_MP4, FT_MAX };

/**
 * struct used to associate a filetype name and its corresponding mimetype.
 */
struct ftype {
	const char *const nametype;	/**< Display name of the filetype */
	const char *const mimetype;	/**< Mime type associated to the filetype */
};
extern const struct ftype const filetype[];

#define NEW_ENT(pool) ((mu_ent *)ap_pcalloc(pool, sizeof(mu_ent)))

mu_ent *make_music_entry(request_rec *, apr_pool_t *,
	mu_ent *const, const mu_config *const, mu_ent_names *, unsigned long);

mu_ent *build_custom_list(request_rec *r, const mu_config *const conf);

#endif	/* PLAYLIST_H */

==> libapache-mod-musicindex_1.2.2.orig.tar.gz: libapache-mod-musicindex-1.2.2/src/playlist.h <==
/*
 *  playlist.h
 *  mod_musicindex
 *
 *  $Id: playlist.h 742 2007-04-23 13:15:36Z varenet $
 *
 *  Created by Thibaut VARENE on Thu Mar 20 2003.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef PLAYLIST_H
#define PLAYLIST_H

#include "mod_musicindex.h"

/**
 * Function pointer type, as we need it.
 *
 * Here comes the declaration of the funny part... We will (again) use
 * function pointers which will allocate a new entry  from the apache pool,
 * fill it, and close the "in" file if they recognise the file.
 */
typedef mu_ent* (*make_entry_ptr)(request_rec *, apr_pool_t *, FILE *const,
				const mu_config *const, mu_ent_names *const);

/**
 * Enumerate handlers to access relevant data in struct filetype.
 * FT_MAX is the last element of the enum, it's a marker that gives
 * us the size of the corresponding array.
 *
 * @warning <b>BEWARE</b>: you must keep that in a coherent order wrt
 * struct filetype[] !
 */
enum { FT_MP3, FT_OGG, FT_FLAC, FT_MP4, FT_MAX };

/**
 * struct used to associate a filetype name and its corresponding mimetype.
 */
struct ftype {
	const char *const nametype;	/**< Display name of the filetype */
	const char *const mimetype;	/**< Mime type associated to the filetype */
};
extern const struct ftype const filetype[];

#define NEW_ENT(pool) ((mu_ent *)ap_pcalloc(pool, sizeof(mu_ent)))

void make_music_entry(request_rec *, apr_pool_t *,
	mu_pack *const, const mu_config *const, mu_ent_names *, unsigned long);

void build_custom_list(request_rec *, mu_pack *const, const mu_config *const);

#endif	/* PLAYLIST_H */
